@@ -11,12 +11,14 @@ use strict;
 use warnings;
 
 package Dist::Zilla::Plugin::Git::Tag;
-# ABSTRACT: tag the new version
-$Dist::Zilla::Plugin::Git::Tag::VERSION = '2.036';
+# ABSTRACT: Tag the new version
+
+our $VERSION = '2.040';
 
 use Moose;
 use MooseX::Has::Sugar;
 use MooseX::Types::Moose qw{ Str Bool};
+use namespace::autoclean;
 
 sub _git_config_mapping { +{
    changelog => '%{changelog}s',
@@ -36,6 +38,14 @@ with 'Dist::Zilla::Role::BeforeRelease',
 with 'Dist::Zilla::Role::Git::StringFormatter';
 with 'Dist::Zilla::Role::GitConfig';
 
+#pod =method tag
+#pod
+#pod     my $tag = $plugin->tag;
+#pod
+#pod Return the tag that will be / has been applied by the plugin. That is,
+#pod returns C<tag_format> as completed with the real values.
+#pod
+#pod =cut
 
 has tag => ( ro, isa => Str, lazy_build => 1, );
 
@@ -99,11 +109,11 @@ __END__
 
 =head1 NAME
 
-Dist::Zilla::Plugin::Git::Tag - tag the new version
+Dist::Zilla::Plugin::Git::Tag - Tag the new version
 
 =head1 VERSION
 
-version 2.036
+version 2.040
 
 =head1 SYNOPSIS
 
@@ -164,11 +174,24 @@ returns C<tag_format> as completed with the real values.
 =for Pod::Coverage after_release
     before_release
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-Git>
+(or L<bug-Dist-Zilla-Plugin-Git@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-Git@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://www.listbox.com/subscribe/?list_id=139292>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
+
+I am also usually active on irc, as 'ether' at C<irc.perl.org>.
+
 =head1 AUTHOR
 
 Jerome Quelin
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2009 by Jerome Quelin.
 
