@@ -11,11 +11,13 @@ use strict;
 use warnings;
 
 package Dist::Zilla::PluginBundle::Git;
-# ABSTRACT: all git plugins in one go
-$Dist::Zilla::PluginBundle::Git::VERSION = '2.036';
+# ABSTRACT: All git plugins in one bundle
+
+our $VERSION = '2.040';
 
 use Moose;
 use Module::Runtime 'use_module';
+use namespace::autoclean;
 
 with 'Dist::Zilla::Role::PluginBundle';
 
@@ -63,11 +65,11 @@ __END__
 
 =head1 NAME
 
-Dist::Zilla::PluginBundle::Git - all git plugins in one go
+Dist::Zilla::PluginBundle::Git - All git plugins in one bundle
 
 =head1 VERSION
 
-version 2.036
+version 2.040
 
 =head1 SYNOPSIS
 
@@ -125,11 +127,24 @@ After a release, push the released code & tag to your public repo.
 For a list of Git plugins in this distribution that are not part of
 this bundle, see L<Dist::Zilla::Plugin::Git>.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-Git>
+(or L<bug-Dist-Zilla-Plugin-Git@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-Git@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://www.listbox.com/subscribe/?list_id=139292>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
+
+I am also usually active on irc, as 'ether' at C<irc.perl.org>.
+
 =head1 AUTHOR
 
 Jerome Quelin
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2009 by Jerome Quelin.
 
