@@ -8,13 +8,24 @@
 #
 package Dist::Zilla::Role::Git::Repo;
 # ABSTRACT: Provide repository information for Git plugins
-$Dist::Zilla::Role::Git::Repo::VERSION = '2.036';
+
+our $VERSION = '2.040';
 
 use Moose::Role;
 use MooseX::Types::Moose qw(Str Maybe);
+use namespace::autoclean;
 
 has 'repo_root'   => ( is => 'ro', isa => Str, default => '.' );
 
+#pod =method current_git_branch
+#pod
+#pod   $branch = $plugin->current_git_branch;
+#pod
+#pod The current branch in the repository, or C<undef> if the repository
+#pod has a detached HEAD.  Note: This value is cached; it will not
+#pod be updated if the branch is changed during the run.
+#pod
+#pod =cut
 
 has current_git_branch => (
     is => 'ro',
@@ -37,6 +48,16 @@ sub _build_current_git_branch
   $branch;
 } # end _build_current_git_branch
 
+#pod =method git
+#pod
+#pod   $git = $plugin->git;
+#pod
+#pod This method returns a Git::Wrapper object for the C<repo_root>
+#pod directory, constructing one if necessary.  The object is shared
+#pod between all plugins that consume this role (if they have the same
+#pod C<repo_root>).
+#pod
+#pod =cut
 
 my %cached_wrapper;
 
@@ -49,6 +70,7 @@ around dump_config => sub
 
     $config->{+__PACKAGE__} = {
         repo_root => $self->repo_root,
+        'git --version' => $self->git('version'),
     };
 
     return $config;
@@ -77,7 +99,7 @@ Dist::Zilla::Role::Git::Repo - Provide repository information for Git plugins
 
 =head1 VERSION
 
-version 2.036
+version 2.040
 
 =head1 DESCRIPTION
 
@@ -109,11 +131,24 @@ directory, constructing one if necessary.  The object is shared
 between all plugins that consume this role (if they have the same
 C<repo_root>).
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-Git>
+(or L<bug-Dist-Zilla-Plugin-Git@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-Git@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://www.listbox.com/subscribe/?list_id=139292>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
+
+I am also usually active on irc, as 'ether' at C<irc.perl.org>.
+
 =head1 AUTHOR
 
 Jerome Quelin
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2009 by Jerome Quelin.
 
